@@ -143,11 +143,11 @@ sub update ($self, %args) {
     # warn about old files (data may be redundant or obsolete though)
     foreach my $old_path (sort keys %old_split_files) {
         # prepare to be able to put back data matching an existing dir
-        if ($old_path eq '*' or ($old_path =~ m!(.*)/\*$! and $current_dir->is_dir($1))) {
+        if ($old_path eq '*' or ($old_path =~ m!(.*)/\*$! and $current_dir->child($1)->is_dir )) {
             $preserved_path{$old_path} = delete $old_split_files{$old_path};
         }
         else {
-            $self->_say( "Note: '$old_path' was removed from new upstream source" );
+            $self->_say( "Note: '$old_path' was removed (or excluded) from new upstream source" );
         }
     }
 
@@ -287,6 +287,8 @@ sub update ($self, %args) {
     # normalized again after all the modifications
     $self->load("Files:.sort");
 
+    $self->prune_unused_global_licenses;
+
     $self->instance->clear_changes; # too many changes to show users
     $self->notify_change(note => "updated copyright from source file"); # force a save
 
@@ -301,6 +303,23 @@ sub update ($self, %args) {
     return @msgs;
 }
 
+sub prune_unused_global_licenses ($self) {
+    my %global_license = map { $_ => 1 } $self->fetch_element("License")->fetch_all_indexes;
+
+    foreach my $path ($self->fetch_element('Files')->fetch_all_indexes) {
+        my $lic = $self->grab(qq!Files:"$path" License!);
+        next if $lic->fetch_element_value("full_license"); # no need of a global License
+        my $names = $lic->fetch_element_value("short_name") ;
+        my @sub_licenses = split /\s+or\s+/,$names;
+        map { delete $global_license{$_}; } @sub_licenses;
+    }
+
+    foreach my $obsolete_lic (sort keys %global_license) {
+        say "Deleting unused global license $obsolete_lic";
+        $self->load(qq!License:-"$obsolete_lic"!);
+    }
+}
+
 sub _apply_fix_scan_copyright_file ($self, $current_dir) {
     # read a debian/fix.scanned.copyright file to patch scanned data
     my $debian = $current_dir->child('debian'); # may be missing in test environment
