@@ -203,20 +203,32 @@ depend: pkg_dep | variable
 variable: /\$\{[\w:\-]+\}[\w\.\-~+]*/
 
 pkg_dep: pkg_name dep_version(?) arch_restriction(?) profile_restriction(s?) {
-    my $dv = $item[2] ;
-    my $ar = $item[3] ;
-    my @ret = ( $item{pkg_name} ) ;
-    if    (@$dv and @$ar) { push @ret, @{$dv->[0]}, @{$ar->[0]} ;}
-    elsif (@$dv)          { push @ret, @{$dv->[0]} ;}
-    elsif (@$ar)          { push @ret, undef, undef, @{$ar->[0]} ;}
-    $return = \@ret ; ;
-   }
+    my %ret = ( name => $item{pkg_name} );
+    $ret{dep}     = $item[2][0] if @{$item[2]};
+    $ret{arch}    = $item[3][0] if @{$item[3]};
+    $ret{profile} = $item[4] if @{$item[4]};
+    $return = \%ret ;
+}
 
-profile_restriction: '<' profile(s) '>'
+# see https://wiki.debian.org/BuildProfileSpec
+profile_restriction: '<' profile(s) '>' { $return = $item[2]; }
 
-profile: not(?) profile_name
+profile: not(?) profile_name profile_extention(?) {
+  $return = join('', @{$item[1]}, $item{profile_name}, @{$item[3]});
+}
 
-profile_name: /[a-z][a-z0-9-]*/
+profile_extention: '.' /[\w\-]+/ '.' /[\w-]+/ {
+    $return = join('', @item[1..4]) ;
+}
+
+profile_name: 'cross' | 'pkg' | 'stage1'| 'stage2' |
+   'nobiarch' | 'nocheck' | 'nodoc' | 'nogolang' | 'nojava' | 'noperl' | 'nopython' | 'noudeb' |
+{
+    my @a = ('cross', 'pkg', 'stage1', 'stage2',
+            'nobiarch', 'nocheck', 'nodoc', 'nogolang', 'nojava', 'noperl', 'nopython', 'noudeb');
+    my ($bad) = split / /, $text;
+    $add_error->("Unknown build profile name '$bad'","Expected one of @a") ;
+}
 
 arch_restriction: '[' osarch(s) ']'
     {
@@ -352,10 +364,11 @@ sub check_dependency {
 }
 
 sub check_debhelper_version {
-    my ($self, $apply_fix, $depend) = @_ ;
-    my ( $dep_name, $oper, $dep_v, @archs ) = @$depend ;
+    my ($self, $apply_fix, $dep_info) = @_ ;
+    my $dep_name = $dep_info->{name};
+    my ($oper, $dep_v) = @{ $dep_info->{dep} || []};
 
-    my $dep_string = $self->struct_to_dep($depend) ;
+    my $dep_string = $self->struct_to_dep($dep_info) ;
     my $lintian_dep = Lintian::Relation->new( $dep_string ) ;
     $logger->debug("checking '$dep_string' with lintian");
 
@@ -381,7 +394,7 @@ sub check_debhelper_version {
     # $show_rel avoids undef warnings
     my $show_rel = join(' ', map { $_ || ''} ($oper, $dep_v));
     if ($apply_fix) {
-        @$depend = ( 'debhelper', '>=', $compat_value ) ; # notify_change called in check_value
+        $dep_info->{dep} = [ '>=', $compat_value] ; # notify_change called in check_value
         $logger->info("fixed debhelper dependency from "
             ."$dep_name $show_rel -> ".$min_dep->unparse." (for compat $compat_value)");
     }
@@ -410,23 +423,29 @@ sub struct_to_dep {
     my @alternatives ;
     foreach my $d (@input) {
         my $line = '';
-        # empty str or ref to empty array are skipped
-        if( ref ($d) and @$d) {
-            $line .= "$d->[0]";
 
-            # skip test for relations like << or <
-            $skip ++ if defined $d->[1] and $d->[1] =~ /</ ;
-            $line .= " ($d->[1] $d->[2])" if defined $d->[2];
+        # empty name is skipped
+        if (ref $d) {
+            my ($name, $dep,$arch, $prof) = @{$d}{qw/name dep arch profile/} ;
+            if ( $name) {
+                $line .= $name;
 
-            if (@$d > 3) {
-                $line .= ' ['. join(' ',@$d[3..$#$d]) .']' ;
+                # skip test for relations like << or <
+                $skip ++ if defined $dep->[0] and $dep->[0] =~ /</ ;
+                $line .= " (@$dep)" if defined $dep->[1];
+
+                $line .= " [@$arch]" if $arch;
+
+                if ($prof) {
+                    foreach my $prof_or (@$prof) {
+                        $line .= ' <'.join(' ',@$prof_or).'>';
+                    }
+                }
             }
-
         }
-        elsif (not ref($d) and $d) {
-            $line .= $d ;
-        } ;
-
+        else {
+            $line .= $d;
+        }
         push @alternatives, $line if $line ;
     }
 
@@ -456,7 +475,8 @@ sub check_depend_chain {
     foreach my $depend (@$input) {
         if (ref ($depend)) {
             # is a dependency (not a variable a la ${perl-Depends})
-            my ($dep_name, $oper, $dep_v) = @$depend ;
+            my $dep_name = $depend->{name};
+            my ($oper, $dep_v) = @{ $depend->{dep} || []};
             $logger->debug("scanning dependency $dep_name"
                 .(defined $dep_v ? " $dep_v" : ''));
             if ($dep_name =~ /lib[\w+\-]+-perl/) {
@@ -486,12 +506,13 @@ sub extract_cpan_version {
 # does modify $input when applying fix
 sub check_perl_lib_dep {
     my ($self, $apply_fix, $actual_dep, $depend, $input) = @_;
-    my ( $dep_name, $oper, $dep_v ) = @$depend;
+    my $dep_name = $depend->{name};
+    my ($oper, $dep_v) = @{ $depend->{dep} || []};
 
     $logger->debug("called for $dep_name with $actual_dep with apply_fix $apply_fix");
 
-    my ($old_perl_dep) = grep { $_->[0] eq 'perl' } @$input;
-    my $old_perl_versioned_dep = $old_perl_dep->[2];
+    my ($old_perl_dep) = grep { $_->{name} eq 'perl' } @$input;
+    my $old_perl_versioned_dep = $old_perl_dep->{dep}[1];
 
     # The dependency should be in the form perl (>= 5.10.1) | libtest-simple-perl (>= 0.88)".
     # cf http://pkg-perl.alioth.debian.org/policy.html#debian_control_handling
@@ -513,9 +534,9 @@ sub check_perl_lib_dep {
 
     return 1 if (defined $dep_v && $dep_v =~ m/^\$/) ; # version like ${foobar}
 
-    my @ideal_perl_dep = qw/perl/ ;
-    my @ideal_lib_dep ;
-    my @ideal_dep_chain = (\@ideal_perl_dep);
+    my %ideal_perl_dep = qw/name perl/ ;
+    my %ideal_lib_dep ;
+    my @ideal_dep_chain = (\%ideal_perl_dep);
 
     my @res = $self->get_available_version( $dep_name);
 
@@ -569,13 +590,13 @@ sub check_perl_lib_dep {
         $v_normal = $old_perl_versioned_dep;
     }
 
-	my ($has_older_perl) = $self->check_versioned_dep(  ['perl', '>=', $v_normal] );
-	push @ideal_perl_dep, '>=', $v_normal if $has_older_perl;
+	my ($has_older_perl) = $self->check_versioned_dep( { name => 'perl', dep => ['>=', $v_normal]} );
+	$ideal_perl_dep{dep} = [ '>=', $v_normal ] if $has_older_perl;
 
     if ($removed or $deprecated or $has_older_perl) {
         my ($has_older_lib) = $self->check_versioned_dep(  $depend );
-        push @ideal_lib_dep, $dep_name;
-        push @ideal_lib_dep, '>=', $dep_v if $dep_v and $has_older_lib;
+        $ideal_lib_dep{name} = $dep_name;
+        $ideal_lib_dep{dep} = [ '>=', $dep_v ] if $dep_v and $has_older_lib;
     }
 
     my %perl_version =  $self->get_available_version( 'perl');
@@ -588,9 +609,9 @@ sub check_perl_lib_dep {
 	);
 
 	my @ordered_ideal_dep
-        = $removed || $deprecated  ? ( \@ideal_lib_dep )
-        : $has_older_perl_in_sid ? ( \@ideal_perl_dep, \@ideal_lib_dep )
-        :                          ( \@ideal_lib_dep, \@ideal_perl_dep ) ;
+        = $removed || $deprecated  ? ( \%ideal_lib_dep )
+        : $has_older_perl_in_sid ? ( \%ideal_perl_dep, \%ideal_lib_dep )
+        :                          ( \%ideal_lib_dep, \%ideal_perl_dep ) ;
 
 	my $ideal_dep = $self->struct_to_dep( @ordered_ideal_dep );
 
@@ -600,7 +621,9 @@ sub check_perl_lib_dep {
 	if ( $actual_dep ne $ideal_dep ) {
 		if ($apply_fix) {
 			@$input = @ordered_ideal_dep ; # notify_change called in check_value
-			$logger->info("fixed dependency with: $ideal_dep, was @$depend");
+            if ($logger->is_info) {
+                $logger->info("fixed dependency with: $ideal_dep, was ". $self->struct_to_dep($depend));
+            }
 		}
 		else {
 			$self->{nb_of_fixes}++;
@@ -622,7 +645,8 @@ sub check_perl_lib_dep {
 
 sub check_versioned_dep {
     my ($self ,$dep_info) = @_ ;
-    my ( $pkg,  $oper,      $vers )    = @$dep_info;
+    my $pkg = $dep_info->{name};
+    my ($oper, $vers) = @{ $dep_info->{dep} || []};
     $logger->debug("called with '" . $self->struct_to_dep($dep_info) ."'") if $logger->is_debug;
 
     # special case to keep lintian happy
@@ -682,7 +706,8 @@ sub has_older_version_than {
 #
 sub check_or_fix_essential_package {
     my ( $self, $apply_fix, $dep_info ) = @_;
-    my ( $pkg,  $oper,      $vers )    = @$dep_info;
+    my $pkg = $dep_info->{name};
+    my ($oper, $vers) = @{ $dep_info->{dep} || []};
     $logger->debug("called with '", scalar $self->struct_to_dep($dep_info), "' and fix $apply_fix") if $logger->is_debug;
 
     # Remove unversioned dependency on essential package (Debian bug 684208)
@@ -695,7 +720,7 @@ sub check_or_fix_essential_package {
     if ($is_essential and not defined $oper) {
         $logger->debug( "found unversioned dependency on essential package: $pkg");
         if ($apply_fix) {
-            @$dep_info = ();
+            %$dep_info = ();
             $logger->info("fix: removed unversioned essential dependency on $pkg");
         }
         else {
@@ -714,7 +739,7 @@ my %pkg_replace = (
 
 sub check_or_fix_pkg_name {
     my ( $self, $apply_fix, $dep_info, $old ) = @_;
-    my ( $pkg,  $oper,      $vers )    = @$dep_info;
+    my $pkg = $dep_info->{name};
 
     $logger->debug("called with '", scalar $self->struct_to_dep($dep_info), "' and fix $apply_fix")
         if $logger->is_debug;
@@ -751,7 +776,7 @@ sub check_or_fix_pkg_name {
 
 sub check_or_fix_dep {
     my ( $self, $apply_fix, $dep_info, $old ) = @_;
-    my ( $pkg,  $oper,      $vers, @archs )    = @$dep_info;
+    my $pkg = $dep_info->{name};
 
     $logger->debug("called with '", scalar $self->struct_to_dep($dep_info), "' and fix $apply_fix")
         if $logger->is_debug;
@@ -770,15 +795,17 @@ sub check_or_fix_dep {
 
 sub warn_or_remove_vers_dep {
     my ( $self, $apply_fix, $dep_info, $list ) = @_;
-    my ( $pkg,  $oper,      $vers )    = @$dep_info;
+    my $pkg = $dep_info->{name};
+    my ($oper, $vers) = @{ $dep_info->{dep} || []};
 
     if ($apply_fix) {
-        splice @$dep_info, 1, 2;    # remove versioned dep, notify_change called in check_value
-        $logger->info("fix: removed versioned dependency from @$dep_info -> $pkg");
+        delete $dep_info->{dep};    # remove versioned dep, notify_change called in check_value
+        $logger->info("fix: removed versioned dependency from $dep_info->{name} -> $pkg");
     }
     else {
         $self->{nb_of_fixes}++;
-        my $msg = "unnecessary versioned dependency: @$dep_info. Debian has @$list";
+        my $msg = "unnecessary versioned dependency: ". $self-> struct_to_dep($dep_info)
+            . ". Debian has @$list";
         $self->add_warning( $msg);
         $logger->info("will warn: $msg (fix++)");
     }
