@@ -30,6 +30,15 @@ For details, see L<section 5.7 of Debian policy|https://www.debian.org/doc/debia
       },
       'Maintainer',
       {
+        'compute' => {
+          'allow_override' => '1',
+          'formula' => 'my $name = $ENV{DEBFULLNAME};
+my $email = $ENV{DEBEMAIL} ;
+my $ret;
+$ret = "$name <$email>" if defined $name and defined $email;
+$ret;',
+          'use_eval' => '1'
+        },
         'description' => 'The package maintainer\'s name and email address. The name must come first, then the email address inside angle brackets <> (in RFC822 format).
 
 If the maintainer\'s name contains a full stop then the whole field will not work directly as an email address due to a misfeature in the syntax specified in RFC822; a program using this field as an address must check for this and correct the problem if necessary (for example by putting the name in round brackets and moving it to the end, and bringing the email address forward). ',
@@ -49,6 +58,7 @@ If the maintainer\'s name contains a full stop then the whole field will not wor
       },
       'Section',
       {
+        'default' => 'misc',
         'description' => 'The packages in the archive areas main, contrib and non-free are
 grouped further into sections to simplify handling.
 
@@ -176,6 +186,7 @@ in Debian developer reference.',
           'optional',
           'extra'
         ],
+        'default' => 'extra',
         'help' => {
           'extra' => 'This contains all packages that conflict with others with required, important, standard or optional priorities, or are only likely to be useful if you already know what they are or have specialized requirements (such as packages containing only detached debugging symbols).',
           'important' => 'Important programs, including those which one would expect to find on any Unix-like system. If the expectation is that an experienced Unix person who found it missing would say "What on earth is going on, where is foo?", it must be an important package.[5] Other packages without which the system will not run well or be usable must also have priority important. This does not include Emacs, the X Window System, TeX or any other large applications. The important packages are just a bare minimum of commonly-expected and necessary tools.',
