@@ -36,11 +36,14 @@ To upgrade your file from an old spec, run:
         'default' => 'https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/',
         'description' => 'URI of the format specification.',
         'mandatory' => '1',
-        'match' => '^https?://',
         'type' => 'leaf',
         'value_type' => 'uniline',
         'warn_unless_match' => {
-          '^https://www.debian.org/doc/packaging-manuals/copyright-format/1\\.0/?$' => {
+          '^https' => {
+            'fix' => '$_ = undef;',
+            'msg' => 'Format uses insecure http protocol instead of https'
+          },
+          '^https?://www.debian.org/doc/packaging-manuals/copyright-format/1\\.0/?$' => {
             'fix' => '$_ = undef;',
             'msg' => 'Format does not match the recommended URL for DEP-5'
           }
