@@ -95,8 +95,10 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
     },
     { # t7
         # example from CANDIDATE DEP-5 spec (nb 7)
-        load_warnings => [ (qr/Adding/) x 1 , qr/Format does not match/,
-                       qr/trailing slash/],
+        load_warnings => [
+            (qr/Adding/) x 1 , qr/insecure/, qr/Format does not match/,
+            qr/trailing slash/
+        ],
         load_check => 'skip',
         apply_fix => 1,
         check => { 
@@ -108,7 +110,7 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
     },
     {
         # test nb 8
-        load_warnings => [ qr/Format does not match/, qr/many versions/ ],
+        load_warnings => [ qr/insecure/, qr/Format does not match/, qr/many versions/ ],
         apply_fix => 1,
         check => { 
             Format => "https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/", 
@@ -116,7 +118,7 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
         },
     },
     {
-        load_warnings => [ qr/Format does not match/ ,qr/should not match/ ],
+        load_warnings => [  qr/insecure/, qr/Format does not match/ ,qr/should not match/ ],
         apply_fix => 1,
         load => 'Files~"*/share/web/static/[css|js|images]/yui/*"',
         check => {
@@ -139,7 +141,7 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
     },
 
     { # t11 Debian bug #610231
-        load_warnings => [ qr/Format does not match/ ],
+        load_warnings => [  qr/insecure/, qr/Format does not match/ ],
         apply_fix => 1,
         dump_errors =>  [ 
             qr/mandatory/ => 'Files:"*" Copyright="(c) foobar"',
@@ -156,12 +158,12 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
     },
 
     { # t13 Debian bug #624305
-        load_warnings => [ qr/Format does not match/ ],
+        load_warnings => [  qr/insecure/, qr/Format does not match/ ],
         apply_fix => 1,
     },
     { # t14 Debian bug #633847
         # need to change License model from Hash of leaves to hash of nodes 
-        load_warnings => [ qr/Format does not match/ ],
+        load_warnings => [  qr/insecure/, qr/Format does not match/ ],
         apply_fix => 1,
         check => { 
             'Comment' => "On Debian systems, copies of the GNU General Public License version 1
@@ -207,7 +209,7 @@ in ‘/usr/share/common-licenses/GPL-1’.",
     },
     {
         name => 'oar',
-        load_warnings => [ qr/Format does not match/, qr/use Expat/ ],
+        load_warnings => [  qr/insecure/, qr/use Expat/ ],
         no_warnings => 1,
         apply_fix => 1,
 
