@@ -14,6 +14,7 @@ $skip = ( $@ or not -r '/etc/debian_version' ) ? 1 : 0;
     {
         name => 'libperl5i' ,
         config_file => $conf_file_name,
+        load_warnings => [ qr/https protocol should/  ],
         apply_fix => 1 ,
         check => {
             'Synopsis' => qr/test TODO/,
@@ -23,7 +24,7 @@ $skip = ( $@ or not -r '/etc/debian_version' ) ? 1 : 0;
             'Bug:0' => 'https://github.com/schwern/perl5i/issues/218',
             'Bug:1' => 'https://github.com/schwern/perl5i/issues/219',
             'Origin' => 'https://github.com/doherty/perl5i',
-            'Bug-Debian:0' => 'http://bugs.debian.org/655329',
+            'Bug-Debian:0' => 'https://bugs.debian.org/655329',
 
         },
         # file_check_sub => $del_home,
